@@ -45,7 +45,7 @@ class FacebookScraper:
         self.requests_kwargs = requests_kwargs
 
     def get_posts(self, account: str, **kwargs) -> Iterator[Post]:
-        iter_pages_fn = partial(iter_pages, account=account, request_fn=self.get, cookie_locale=kwargs['cookie_locale'])
+        iter_pages_fn = partial(iter_pages, account=account, request_fn=self.get)
         return self._generic_get_posts(extract_post, iter_pages_fn, **kwargs)
 
     def get_group_posts(self, group: str, **kwargs) -> Iterator[Post]:
@@ -60,9 +60,6 @@ class FacebookScraper:
                     'http': os.getenv('SOCIAL_METRIC_HTTP_PROXY'),
                     'https': os.getenv('SOCIAL_METRIC_HTTPS_PROXY')
                 }
-            if 'cookie_locale' in kwargs:
-                self.default_headers['cookie'] = 'locale=%s;' % kwargs['cookie_locale']
-                self.session.headers.update(self.default_headers)
             response = self.session.get(url=url, **self.requests_kwargs, **kwargs)
             response.raise_for_status()
             return response
@@ -93,9 +90,7 @@ class FacebookScraper:
         return not response.url.startswith('https://m.facebook.com/login.php')
 
     def _generic_get_posts(
-            self, extract_post_fn, iter_pages_fn, page_limit=DEFAULT_PAGE_LIMIT, options=None
-    , cookie_locale=None):
-        print("cookie_locale:%s" % cookie_locale)
+            self, extract_post_fn, iter_pages_fn, page_limit=DEFAULT_PAGE_LIMIT, options=None):
         counter = itertools.count(0) if page_limit is None else range(page_limit)
 
         if options is None:
@@ -105,4 +100,4 @@ class FacebookScraper:
         for i, page in zip(counter, iter_pages_fn()):
             logger.debug("Extracting posts from page %s", i)
             for post_element in page:
-                yield extract_post_fn(post_element, options=options, request_fn=self.get, cookie_locale=cookie_locale)
+                yield extract_post_fn(post_element, options=options, request_fn=self.get)
